@@ -12,6 +12,15 @@ asset_path_templates = {
 }
 
 
+def user_info(request: Request):
+    encoded_user_info = request.headers.get("X-Endpoint-Api-Userinfo")
+    if encoded_user_info:
+        if not encoded_user_info.endswith("=="):
+            encoded_user_info += "=="
+        return json.loads(urlsafe_b64decode(encoded_user_info))
+    return {}
+
+
 def authorize(request, asset, permission):
     uid = user_info(request)["user_id"]
     resp = call("check_permission", uid=uid, asset=asset, permission=permission)
@@ -32,7 +41,6 @@ def auth(permission):
                 resp.status_code = 400
                 abort(resp)
             authorize(request, asset, permission)
-            request.headers["X-Authorized-Asset"] = asset
             return func(request)
 
         return wrapped_func
@@ -40,14 +48,15 @@ def auth(permission):
     return wrap
 
 
-def authorized_asset(request: Request):
-    return request.headers.get("X-Authorized-Asset")
-
-
-def user_info(request: Request):
-    encoded_user_info = request.headers.get("X-Endpoint-Api-Userinfo")
-    if encoded_user_info:
-        if not encoded_user_info.endswith("=="):
-            encoded_user_info += "=="
-        return json.loads(urlsafe_b64decode(encoded_user_info))
-    return {}
+class ParsedRequest:
+    def __init__(self, request: Request):
+        data = request.json
+        self.user_info = user_info(request)
+        self.data = data
+        self.repo = "{}-{}".format(data.get("wid"), data.get("cid"))
+        self.change_ref = "{}/{}/{}".format(
+            data.get("sid"), self.user_info.get("user_id"), data.get("change_id")
+        )
+        self.plan_ref = "tf/plan/{}".format(self.change_ref)
+        self.apply_ref = "tf/apply/{}".format(data.get("sid"))
+        self.source_apply_ref = "tf/apply/{}".format(data.get("source_sid"))
